# SAPHIRES
SAPHIRES - Stellar Analysis in Python for HIgh REsolution Spectroscopy

[![DOI](https://zenodo.org/badge/183699708.svg)](https://zenodo.org/badge/latestdoi/183699708)


## Installation

`pip install saphires`


## Description

This python package includes some common tools for the analysis of high resolution spectra 
that don't typically have easily accessible python versions.

It currently includes:

- Spectral-Line Broadening Functions

- TODCOR (Two-Dimensional Cross Correlation)

It will soon include the following tools:

- Fourier Cross Correlation


There is also a utilities module (utils) that has some generally useful functions:

- Air to vacuum wavelength conversions, and vice versa (vac2air, air2vac)

- Continuum normalization (cont_norm)

- With more to come...

## Documentation

See the [documentation](https://saphires.readthedocs.io/en/latest/index.html) for information on how to install and use saphires.



This code is actively being developed with the help of Danny Krolikowski, Natalie Gosnell, Emily Leiner, Victoria Catlett, and Miguel Gutierrez.


